let gameState = {
  board: Array(9).fill(null),
  currentPlayer: 'X',
  winner: null
};

const winPatterns = [
  [0, 1, 2], [3, 4, 5], [6, 7, 8], // Rows
  [0, 3, 6], [1, 4, 7], [2, 5, 8], // Columns
  [0, 4, 8], [2, 4, 6] // Diagonals
];

const checkWinner = (board) => {
  for (const pattern of winPatterns) {
    const [a, b, c] = pattern;
    if (board[a] && board[a] === board[b] && board[a] === board[c]) {
      return board[a];
    }
  }
  return null;
};

const handleCellClick = async (index) => {
  if (gameState.board[index] || gameState.winner) return;
  
  gameState.board[index] = gameState.currentPlayer;
  const cell = document.querySelector(`[data-index="${index}"]`);
  cell.textContent = gameState.currentPlayer;
  cell.classList.add(gameState.currentPlayer.toLowerCase());
  
  const winner = checkWinner(gameState.board);
  if (winner) {
    gameState.winner = winner;
    document.querySelector('.gameStatus').textContent = `Player ${winner} wins!`;
  } else if (!gameState.board.includes(null)) {
    document.querySelector('.gameStatus').textContent = "It's a draw!";
  } else {
    gameState.currentPlayer = gameState.currentPlayer === 'X' ? 'O' : 'X';
    document.querySelector('.gameStatus').textContent = `Player ${gameState.currentPlayer}'s turn`;
  }
};

document.querySelectorAll('.cell').forEach((cell, index) => {
  cell.addEventListener('click', () => handleCellClick(index));
});

document.addEventListener('DOMContentLoaded', () => {
  document.querySelector('.gameStatus').textContent = `Player ${gameState.currentPlayer}'s turn`;
});
